BenchmarkEvent

Enum BenchmarkEvent 

#[non_exhaustive]
pub enum BenchmarkEvent<'a> { Started { backend: Backend, parallel_jobs: Option<usize>, }, GlobalWarmupStarted, GlobalWarmupFinished(Duration), RepetitionStarted(u64), RepetitionFinished(&'a RepetitionReport), }
Available on non-WebAssembly only.
One event of a running benchmark, in the order they happen.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Started

Reported before any repetition, after a probe build of a CPU model. A GPU model is not probed.

Fields

backend: Backend

Backend the model runs on.

parallel_jobs: Option<usize>

Number of jobs one step of the probe build split into. None for a GPU model.



GlobalWarmupStarted

The global warm-up is about to build its state and run its steps.



GlobalWarmupFinished(Duration)

The global warm-up ran its steps in this time.



RepetitionStarted(u64)

The repetition at this position, from 0, is about to build its state, run its warm-up and time its steps.



RepetitionFinished(&'a RepetitionReport)

A repetition ended, its timed steps and the actions due on its last tick included.