pub enum CursorState {
Running,
Finished(RunOutcome),
}Expand description
Result of one RunCursor::advance.
Variants
Running
The run has ticks left to step.
Finished(RunOutcome)
The run has ended, at its final tick, on its stop condition, on a fault or past its timeout.