Module device

Module device 

Available on non-WebAssembly only.
A GPU device acquired with no window or surface.

Native only. pollster blocks on the request, and a browser cannot block.

Enums

DeviceError
Failure to acquire a headless device.

Functions

acquire_headless
Acquires a headless device for needs, with its adapter’s RuntimeInfo attached to the context.