pub enum BatchEnd {
Complete,
Aborted,
DeviceLost,
}Expand description
End of a batch that did not fail.
Variants
Complete
Every request was committed.
Aborted
The control aborted the batch. The runs committed before it are a prefix of the requests.
DeviceLost
The GPU device was lost. The runs committed before it are a prefix of the requests, and the rest have no outcome.