pub struct ActiveRuns { /* private fields */ }Expand description
Runs in progress and the tick each has reached, and the finished runs waiting to be committed, shared by clones.
Implementations
Sourceimpl ActiveRuns
impl ActiveRuns
Sourcepub fn waiting_count(&self) -> usize
pub fn waiting_count(&self) -> usize
Number of runs that finished and wait for an earlier run to be committed.
Note that a batch that ends before committing every run leaves the runs still waiting in the count.
Sourcepub fn watch(&self, run: PlannedRun, end_tick: u64) -> RunWatch
pub fn watch(&self, run: PlannedRun, end_tick: u64) -> RunWatch
Adds run at tick 0, ending at end_tick, and returns the watch that moves it on and removes it on drop.
Sourcepub fn mark_committed(&self, run_id: u64)
pub fn mark_committed(&self, run_id: u64)
Removes run run_id from the runs waiting to be committed.