pub struct GpuTrackDepth {
pub submissions_per_track: usize,
pub steps_per_submission: u32,
}Expand description
Command buffers and steps each GPU track keeps on the device.
Fields
submissions_per_track: usizeMaximum number of command buffers of one track on the device at once.
steps_per_submission: u32Maximum number of steps in one command buffer, no more than MAX_STEPS_PER_SUBMISSION.