pub enum OutputError {
HoldsResults {
dir: PathBuf,
file: String,
},
Locked {
dir: PathBuf,
},
Link {
path: PathBuf,
},
Read {
path: PathBuf,
source: Error,
},
Write {
path: PathBuf,
source: Error,
},
Table(ReadError),
Summary(SummaryError),
Manifest(Error),
}Expand description
Results that cannot be written.
Variants
HoldsResults
Directory dir holds file from an earlier sweep or search.
Fields
Locked
Another sweep, search or merge holds the lock of directory dir and writes to it.
Link
The table at path is a symbolic link. A writer never follows a symbolic link.
Read
Reading path failed.
Fields
Write
Creating or writing path failed.
Fields
Table(ReadError)
A table that cannot be read back.
Summary(SummaryError)
runs.csv cannot be summarized.
Manifest(Error)
Serializing the manifest failed.