pub struct SweepFiles {
pub runs: Vec<u8>,
pub series: Vec<u8>,
pub summary: Vec<u8>,
pub manifest: Vec<u8>,
pub search_tables: Vec<(&'static str, Vec<u8>)>,
}Expand description
The four files of a sweep, and the tables a search adds.
Fields
runs: Vec<u8>Bytes of runs.csv.
series: Vec<u8>Bytes of series.csv.
summary: Vec<u8>Bytes of summary.csv.
manifest: Vec<u8>Bytes of manifest.json.
search_tables: Vec<(&'static str, Vec<u8>)>Tables a search writes, each with its file name, in the order they are listed. Empty for a sweep.
Implementations
Sourceimpl SweepFiles
impl SweepFiles
Sourcepub fn entries(&self) -> Vec<(&'static str, &[u8])>
pub fn entries(&self) -> Vec<(&'static str, &[u8])>
Returns each file with its name in an output directory, in the order runs, series, summary and manifest, then the search tables.
Sourcepub fn into_entries(self) -> Vec<(String, Vec<u8>)>
pub fn into_entries(self) -> Vec<(String, Vec<u8>)>
Returns each file with its name in an output directory, in the form crate::result_set::ResultSet::from_files
reads.