ReadError

Enum ReadError 

pub enum ReadError {
    Io {
        path: PathBuf,
        source: Error,
    },
    Csv {
        path: PathBuf,
        record_number: usize,
        source: CsvError,
    },
    MissingColumn {
        path: PathBuf,
        column: &'static str,
    },
    FieldCount {
        path: PathBuf,
        record_number: usize,
        found: usize,
        expected: usize,
    },
    BadField {
        path: PathBuf,
        record_number: usize,
        column: String,
        text: String,
    },
}
A table that cannot be read back.

Variants



Io

Reading path failed.

Fields

path: PathBuf

Path of the table, or its bare file name for a table read without a path.

source: Error

Error from the reader, of kind InvalidData for text that is not UTF-8.



Csv

Record record_number of path is not valid CSV.

Fields

path: PathBuf

Path of the table, or its bare file name for a table read without a path.

record_number: usize

Number of the record, counting the header as record 1.

source: CsvError

Error from the CSV parser.



MissingColumn

A header of path without the column column.

Fields

path: PathBuf

Path of the table, or its bare file name for a table read without a path.

column: &'static str

Name of the missing column.



FieldCount

Record record_number of path with a different number of fields from its header.

Fields

path: PathBuf

Path of the table, or its bare file name for a table read without a path.

record_number: usize

Number of the record, counting the header as record 1.

found: usize

Number of fields in the record.

expected: usize

Number of fields in the header.



BadField

Field column of record record_number of path, holding text that the column cannot accept.

Fields

path: PathBuf

Path of the table, or its bare file name for a table read without a path.

record_number: usize

Number of the record, counting the header as record 1.

column: String

Name of the column holding the field, or value for a stat value that a result set reads from series.csv.

text: String

Text of the field, or of the whole line where a series.csv run id cannot be read.