pub struct SeriesScan {
pub path: PathBuf,
pub header: Option<String>,
pub segments: Vec<Range<u64>>,
pub complete_bytes: u64,
pub file_bytes: u64,
pub first_dropped_offset: Option<u64>,
pub kept_after_dropped: bool,
}Expand description
Layout of a series.csv: its header, and the stretches of complete lines in order of their run ids.
Fields
path: PathBufPath of the scanned file.
header: Option<String>Header line as written with its line ending, None for a file with no complete header.
segments: Vec<Range<u64>>Byte ranges of the longest stretches of complete lines whose run ids never decrease, in file order.
complete_bytes: u64Number of bytes up to the end of the file’s last complete line.
file_bytes: u64Size in bytes of the file, 0 for a missing file.
first_dropped_offset: Option<u64>Offset of the first complete line the scan’s rule left out.
kept_after_dropped: boolWhether a line that the rule kept comes after a line that it left out.
Implementations