pub struct ProgressMeter { /* private fields */ }Expand description
Counter of finished runs that yields an update at most once per PROGRESS_INTERVAL.
Implementations
Sourceimpl ProgressMeter
impl ProgressMeter
Sourcepub fn record_finished_run(
&mut self,
status: RunStatus,
) -> Option<ProgressUpdate>
pub fn record_finished_run( &mut self, status: RunStatus, ) -> Option<ProgressUpdate>
Counts a finished run with status. Returns an update once PROGRESS_INTERVAL has passed since the last
update.
Sourcepub fn update(&self) -> ProgressUpdate
pub fn update(&self) -> ProgressUpdate
Returns the update for the runs counted so far.