pub enum ResultSetError {
Missing {
file: &'static str,
},
Duplicate {
file: &'static str,
},
Manifest(ManifestError),
Spec(SpecFileError),
Search(SearchSpecError),
Table(ReadError),
}Expand description
Results that cannot be read.
Variants
Missing
The directory or the files passed in lack file.
Duplicate
Two of the files passed in hold file.
Fields
Manifest(ManifestError)
The manifest cannot be read.
Spec(SpecFileError)
The manifest’s spec cannot be read back.
Search(SearchSpecError)
The search the manifest records has a setting that SearchSpec::check rejects.
Table(ReadError)
A table cannot be read.