SpecFileError

Enum SpecFileError 

pub enum SpecFileError {
Show 14 variants Read { path: PathBuf, source: Error, }, TablePath { block: usize, path: PathBuf, }, Parse { source: Box<Error>, }, Json { source: Error, }, FactorTarget { block: usize, }, FactorLevels { block: usize, target_name: String, }, Design { block: usize, reason: &'static str, }, Reducer(ReducerError), Stop(StopError), Timeout { seconds: f64, }, Search { reason: &'static str, }, SearchFactorTarget, SearchFactorLevels { target_name: String, }, Write { source: Error, },
}
A spec file that cannot be read or turned into a sweep spec.

Variants



Read

Reading the file at path failed.

Fields

path: PathBuf

Path of the spec file, or of a design table that it refers to, joined to the spec file’s directory.

source: Error

Error from reading the file, of kind InvalidData for text that is not UTF-8.



TablePath

Table path path of block block, absolute or holding a component other than a name, such as ...

Fields

block: usize

Index of the block, counting from 0.

path: PathBuf

Table path as written in the block’s file key.



Parse

Text that is not a spec file.

Fields

source: Box<Error>

Error from the TOML parser.



Json

JSON that is not a spec file.

Fields

source: Error

Error from the JSON deserializer.



FactorTarget

A factor of block block with none or both of param and action.

Fields

block: usize

Index of the block, counting from 0.



FactorLevels

Factor of block block on the parameter or action target_name, with none or several of values, range and levels.

Fields

block: usize

Index of the block, counting from 0.

target_name: String

Parameter id or action name the factor targets.



Design

Block block, whose keys do not fit its design.

Fields

block: usize

Index of the block, counting from 0.

reason: &'static str

Message that identifies the key at fault, such as samples applies to a random or lhs design.



Reducer(ReducerError)

A reducer kind that cannot be read.



Stop(StopError)

A stop condition that cannot be read.



Timeout

A timeout of seconds that is negative, not a number or too long for a Duration.

Fields

seconds: f64

Value of timeout_s in seconds, as written in the spec.



Search

A [search] table whose keys do not fit its algorithm or the rest of the spec.

Fields

reason: &'static str

Message that identifies the key at fault, such as [search.pse] applies to a pse search.



SearchFactorTarget

A factor of the search space with none or both of param and action.



SearchFactorLevels

A factor of the search space on the parameter or action target_name, with none or several of values, range and levels.

Fields

target_name: String

Parameter id or action name the factor targets.



Write

A spec that cannot be written as TOML.

Fields

source: Error

Error from the TOML serializer.