pub struct PatternAxisTable {
pub column: String,
pub min: Option<f64>,
pub max: Option<f64>,
pub cells: u32,
}Expand description
One axis of a Pattern Space Exploration’s grid, as { column, min, max, cells }, or as { column, cells } for a
range taken from the initial samples.
Fields
column: StringReducer column, as in Infected:max.
min: Option<f64>Lower bound, left out with max for an automatic range.
max: Option<f64>Upper bound, left out with min for an automatic range.
cells: u32Number of cells from min to max.