check_model_set

Function check_model_set 

pub fn check_model_set(models: &ModelSet, settings: &CheckSettings) -> SetReport
Available on crate features testing only.
Checks every model of models, in the set’s order.

The report also lists every model id that an override or an exemption in settings specifies and that is missing from the set.