SetReport

Struct SetReport 

pub struct SetReport { /* private fields */ }
Available on crate features testing only.
Reports of every model of a set, and the model ids that the settings specify and that are missing from the set.

Implementations

Source

impl SetReport

pub fn reports(&self) -> &[ModelReport]

Report of each model, in the set’s order.

pub fn unknown_models(&self) -> &[String]

Model ids that an override or an exemption specifies and that are missing from the set, each once.

pub fn passed(&self) -> bool

Returns whether every model passed and the settings specify no model missing from the set.

pub fn assert_passed(&self)

Asserts that every model passed and the settings specify no model missing from the set.

Panics

Panics with a summary line, then every model’s report and every model id missing from the set.