#[non_exhaustive]pub struct TestDeviceRequest { /* private fields */ }Available on crate features
testing only.Expand description
Limits and features to request for a test device.
Implementations
Sourceimpl TestDeviceRequest
impl TestDeviceRequest
Sourcepub fn baseline() -> Self
pub fn baseline() -> Self
Returns a request for wgpu::Limits::default(), the WebGPU baseline a browser offers.
Sourcepub fn raised(needs: GpuNeeds) -> Self
pub fn raised(needs: GpuNeeds) -> Self
Returns a request for the baseline raised by henad_compute::gpu::limits::raise for needs, as a host’s
device is raised.
Note that a browser without those limits rejects a model that needs them.
Sourcepub fn features(self, features: Features) -> Self
pub fn features(self, features: Features) -> Self
Requests features as well. headless_test_device returns None for this request on an adapter without them.
A caller can name the type of features as henad_compute::gpu::wgpu::Features, without a direct wgpu
dependency.