pub fn gpu_memory_budget(budget: Option<u64>, ctx: &GpuContext) -> u64Expand description
Returns the device memory budget in bytes for all GPU runs together on ctx: budget when given, and otherwise
the device’s largest buffer.
Note that wgpu reports no total for the device’s memory. The largest buffer is used instead.