pub enum MergeError {
Show 14 variants
NoInputs,
Manifest(ManifestError),
Table(ReadError),
BadShard {
dir: PathBuf,
},
NoTables,
PlanDiffers {
dir: PathBuf,
first: PathBuf,
},
ShardCountDiffers {
dir: PathBuf,
first: PathBuf,
},
SameShard {
shard: Shard,
first: PathBuf,
second: PathBuf,
},
ColumnsDiffer {
dir: PathBuf,
file: &'static str,
},
RunIdDiffers {
dir: PathBuf,
run_id: u64,
config_id: u64,
rep: u64,
},
OutsideShard {
dir: PathBuf,
run_id: u64,
},
DuplicateRun {
dir: PathBuf,
run_id: u64,
},
Output(OutputError),
NotASweep {
dir: PathBuf,
},
}Expand description
Shard directories that cannot be merged.
Variants
NoInputs
A merge with no input directories.
Manifest(ManifestError)
A manifest that cannot be read.
Table(ReadError)
A table that cannot be read back.
BadShard
A manifest in dir whose shard no plan can have.
NoTables
Inputs with no runs.csv or series.csv header between them.
PlanDiffers
Input dir holds a different plan, model schema or replicate count than input first.
Fields
ShardCountDiffers
Input dir splits the plan into a different number of shards than input first.
Fields
SameShard
Inputs first and second both hold shard.
Fields
ColumnsDiffer
file of input dir has different columns from the other inputs.
Fields
RunIdDiffers
Run run_id of input dir, written as replicate rep of config config_id under a different id than the
one that the manifest’s replicate count implies.
Fields
OutsideShard
Run run_id of input dir, outside its shard or past the plan’s runs.
DuplicateRun
Run run_id, listed twice in runs.csv of input dir.
Output(OutputError)
The merged directory cannot be written.
NotASweep
Input dir holds a search. A search runs whole and has no shards.