pub enum SpecFileError {
Show 14 variants
Read {
path: PathBuf,
source: Error,
},
TablePath {
block: usize,
path: PathBuf,
},
Parse {
source: Box<Error>,
},
Json {
source: Error,
},
FactorTarget {
block: usize,
},
FactorLevels {
block: usize,
target_name: String,
},
Design {
block: usize,
reason: &'static str,
},
Reducer(ReducerError),
Stop(StopError),
Timeout {
seconds: f64,
},
Search {
reason: &'static str,
},
SearchFactorTarget,
SearchFactorLevels {
target_name: String,
},
Write {
source: Error,
},
}Expand description
A spec file that cannot be read or turned into a sweep spec.
Variants
Read
Reading the file at path failed.
Fields
TablePath
Table path path of block block, absolute or holding a component other than a name, such as ...
Fields
Parse
Text that is not a spec file.
Json
JSON that is not a spec file.
FactorTarget
A factor of block block with none or both of param and action.
FactorLevels
Factor of block block on the parameter or action target_name, with none or several of values, range
and levels.
Fields
Design
Block block, whose keys do not fit its design.
Fields
Reducer(ReducerError)
A reducer kind that cannot be read.
Stop(StopError)
A stop condition that cannot be read.
Timeout
A timeout of seconds that is negative, not a number or too long for a Duration.
Search
A [search] table whose keys do not fit its algorithm or the rest of the spec.
Fields
SearchFactorTarget
A factor of the search space with none or both of param and action.
SearchFactorLevels
A factor of the search space on the parameter or action target_name, with none or several of values,
range and levels.
Write
A spec that cannot be written as TOML.