pub fn check_model(entry: &ModelEntry, settings: &CheckSettings) -> ModelReportAvailable on crate features
testing only.Expand description
Checks every contract of entry that settings allows, and reports every failure.
An exemption of a check that does not apply to the model fails that check. An override that the model rejects fails
every check that builds the model, including a check skipped for want of a device. With HENAD_REQUIRE_GPU set,
a check that needs a device that the settings do not provide fails as well.