pub fn check_model_set(models: &ModelSet, settings: &CheckSettings) -> SetReportAvailable on crate features
testing only.Expand description
Checks every model of models, in the set’s order.
The report also lists every model id that an override or an exemption in settings specifies and that is
missing from the set.